<?php

namespace Drupal\taxonomy_custom_controller\Controller;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\taxonomy\TermInterface;
use Drupal\taxonomy_custom_controller\Event\TaxonomyCustomControllerEvents;
use Drupal\taxonomy_custom_controller\Event\TermPageBuildEvent;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;

/**
 * Provides custom controller for taxonomy routes.
 */
final class TaxonomyCustomController implements ContainerInjectionInterface {

  /**
   * The event dispatcher.
   *
   * @var \Symfony\Component\EventDispatcher\EventDispatcherInterface
   */
  protected $eventDispatcher;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = new static();
    $instance->eventDispatcher = $container->get('event_dispatcher');
    return $instance;
  }

  /**
   * The build process for term pages.
   *
   * @param \Drupal\taxonomy\TermInterface $taxonomy_term
   *   The taxonomy term entity.
   *
   * @return array|null
   *   The result render array.
   */
  public function build(TermInterface $taxonomy_term) {
    $event = new TermPageBuildEvent($taxonomy_term);
    $this->eventDispatcher->dispatch($event, TaxonomyCustomControllerEvents::PAGE_BUILD);

    $build = $event->getBuildArray();
    if (!empty($build)) {
      return $build;
    }

    return views_embed_view('taxonomy_term', 'page_1', $taxonomy_term->id());
  }

}
